==> endeavour_2.5.2.orig.tar.gz: endeavour-2.5.2/endeavour2/sysinfo/config.h <==
/*
           Endeavour Download Front End Compile Time Configuration
 */

#ifndef CONFIG_SYSINFO_H
#define CONFIG_SYSINFO_H

#include "../config.h"


/*
 *      Program name and version:
 */
#ifdef PROG_NAME
# undef PROG_NAME
#endif

#define PROG_NAME	"SysInfo"



/*
 *	Standard output help message:
 */
#ifdef PROG_HELP_MESG
# undef PROG_HELP_MESG
#endif

#define PROG_HELP_MESG  "\
Usage: sysinfo [options] [GUI_options]\n\
\n\
    [options] can be any of the following:\n\
\n\
        -d <details...>         Details:\n\
                                        load\n\
                                        avg\n\
                                        mem\n\
                                        apm\n\
                                        details\n\
\n\
        -s <style>              Bar Style:\n\
                                        continuous (default)\n\
                                        discrete\n\
                                        led\n\
\n\
        -o <orient>             Bar Orientation:\n\
                                        horizontal (default)\n\
                                        vertical\n\
\n\
        -i <interval>           Poll Interval in milliseconds (default\n\
                                is 250)\n\
\n\
        --help                  Prints (this) help screen and exits.\n\
        --version               Prints version information and exits.\n\
\n\
    [GUI_options] can be any options standard to your GUI, consult\n\
    your GUI's manual for available options.\n\
\n"


#endif	/* CONFIG_SYSINFO_H */

==> endeavour_2.7.3.orig.tar.gz: endeavour-2.7.3/endeavour2/sysinfo/config.h <==
/*
           Endeavour Download Front End Compile Time Configuration
 */

#ifndef CONFIG_SYSINFO_H
#define CONFIG_SYSINFO_H

#include "../config.h"


/*
 *      Program name and version:
 */
#ifdef PROG_NAME
# undef PROG_NAME
#endif

#define PROG_NAME	"SysInfo"



/*
 *	Standard output help message:
 */
#ifdef PROG_HELP_MESG
# undef PROG_HELP_MESG
#endif

#define PROG_HELP_MESG  "\
Usage: sysinfo [options] [GUI_options]\n\
\n\
    The [options] can be any of the following:\n\
\n\
        -d <details...>         Details:\n\
                                        load\n\
                                        avg\n\
                                        mem\n\
                                        apm\n\
                                        details\n\
\n\
        -s <style>              Bar Style:\n\
                                        continuous (default)\n\
                                        discrete\n\
                                        led\n\
\n\
        -o <orient>             Bar Orientation:\n\
                                        horizontal (default)\n\
                                        vertical\n\
\n\
        -i <interval>           Poll Interval in milliseconds (default\n\
                                is 250)\n\
\n\
        --help                  Prints (this) help screen and exits.\n\
        --version               Prints version information and exits.\n\
\n\
    The [GUI_options] can be any options standard to your GUI,\n\
    consult your GUI's manual for available options.\n\
\n"


#endif	/* CONFIG_SYSINFO_H */
